package com.izouma.awesomeadmin.dao;

import java.util.*;

import com.izouma.awesomeadmin.datasource.DataSource;
import org.springframework.stereotype.Repository;
import com.izouma.awesomeadmin.model.LandMark;


/**
 * Dao接口
 */
@Repository("com.zoumaframe.dao.LandMarkMapper")
public interface LandMarkMapper {

    int deleteByPrimaryKey(Integer id);

    int insertSelective(LandMark record);

    LandMark selectByPrimaryKey(Integer id);

    int updateByPrimaryKeySelective(LandMark record);

    List<LandMark> queryAllLandMark(LandMark record);

    List<LandMark> queryLandMarkByPage(Map<String, Object> parameter);

    List<LandMark> queryCityLandMarkByPage(Map<String, Object> parameter);

    int delete(LandMark record);

    LandMark queryLandMark(LandMark record);

    List<LandMark> query(LandMark record);

    LandMark queryLandMarkMapInfo(LandMark record);

    List<LandMark> queryAllLandMarkChild(LandMark record);
}

